@@ -1,9 +1,11 @@
-from . import serialization, stream_io, utils
+from . import serialization, stream_io, torch_compat, utils
+from ._version import __version__
 from .serialization import *
 
 __all__ = [
     *serialization.__all__,
     "stream_io",
+    "torch_compat",
     "utils",
     "protobuf",
     "tensors_pb2",
